package com.fjhx.xmhjc.service.product.impl;

import cn.hutool.core.util.ObjectUtil;
import com.fjhx.file.entity.FileInfoVo;
import com.fjhx.file.utils.ObsFileUtil;
import com.fjhx.tenant.service.dict.DictTenantDataService;
import com.fjhx.xmhjc.entity.product.po.ProductInfo;
import com.fjhx.xmhjc.mapper.product.ProductInfoMapper;
import com.fjhx.xmhjc.service.product.ProductInfoService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.fjhx.xmhjc.utils.DictUtilsByOpen;
import com.ruoyi.common.utils.StringUtils;
import com.ruoyi.common.utils.wrapper.SqlField;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.xmhjc.entity.product.vo.ProductInfoVo;
import com.fjhx.xmhjc.entity.product.dto.ProductInfoSelectDto;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.fjhx.xmhjc.entity.product.dto.ProductInfoDto;
import cn.hutool.core.bean.BeanUtil;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.CollectionUtils;

import javax.annotation.Resource;
import java.util.ArrayList;
import java.util.Arrays;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 * 产品信息表 服务实现类
 * </p>
 *
 * @author hj
 * @since 2023-11-12
 */
@Service
public class ProductInfoServiceImpl extends ServiceImpl<ProductInfoMapper, ProductInfo> implements ProductInfoService {
    @Autowired
    private DictTenantDataService dictTenantDataService;

    @Override
    public List<ProductInfoVo> getList(ProductInfoSelectDto dto) {
        IWrapper<ProductInfo> wrapper = getWrapper();
        wrapper.orderByDesc("pi", ProductInfo::getId);
        wrapper.eq(ObjectUtil.isNotEmpty(dto.getCategoryId()),"category_id", dto.getCategoryId());
        List<ProductInfoVo> list = this.baseMapper.getList(wrapper);
        return list;
    }

    @Override
    public Page<ProductInfoVo> getPage(ProductInfoSelectDto dto) {
        IWrapper<ProductInfo> wrapper = getWrapper();
        wrapper.orderByAsc("pi", ProductInfo::getSort);
        wrapper.keyword(dto, new SqlField("pi", ProductInfo::getTitle));
        Page<ProductInfoVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        List<ProductInfoVo> records = page.getRecords();
//        DictTenantDataSelectDto dictTenantDataSelectDto = new DictTenantDataSelectDto();
//        dictTenantDataSelectDto.setDictCode("product_content_type");
//        List<DictTenantDataVo> dictList = dictTenantDataService.getList(dictTenantDataSelectDto);
        records.forEach(item -> {
            if(StringUtils.isNotBlank(item.getSpec())){
                List<String> list = Arrays.asList(item.getSpec().split(","));
            }
        });
        return page;
    }

    @Override
    public ProductInfoVo detail(Long id) {
        ProductInfo productInfo = this.getById(id);
        ProductInfoVo result = BeanUtil.toBean(productInfo, ProductInfoVo.class);

        Map<String, String> dictMap = DictUtilsByOpen.getDictMap("product_spec");

        List<String> specList = new ArrayList<>();
        if(StringUtils.isNotBlank(productInfo.getSpec())){

            specList = Arrays.stream(productInfo.getSpec().split(",")).map(dictMap::get).collect(Collectors.toList());
        }



        result.setSpecList(specList);


        //获取图片
        List<Long> businessIdList = new ArrayList<>();
        businessIdList.add(result.getId());
        Map<Long, List<FileInfoVo>> fileMap = ObsFileUtil.getFileMap(businessIdList, 1);
        result.setFileList(fileMap.get(result.getId()));

        return result;
    }

    @Override
    public void add(ProductInfoDto productInfoDto) {
        if(!CollectionUtils.isEmpty(productInfoDto.getSpecList())){
            productInfoDto.setSpec(productInfoDto.getSpecList().stream().collect(Collectors.joining(",")));
        }
        this.save(productInfoDto);
        // 保存图片
        ObsFileUtil.saveFile(productInfoDto.getCoverUrlList(), productInfoDto.getId(), 1);


        ObsFileUtil.saveFile(productInfoDto.getContentImgList(), productInfoDto.getId(), 2);
    }

    @Override
    public void edit(ProductInfoDto productInfoDto) {
        if(!CollectionUtils.isEmpty(productInfoDto.getSpecList())){
            productInfoDto.setSpec(productInfoDto.getSpecList().stream().collect(Collectors.joining(",")));
        }
        this.updateById(productInfoDto);
        // 保存图片
        ObsFileUtil.editFile(productInfoDto.getCoverUrlList(), productInfoDto.getId(), 1);


        ObsFileUtil.editFile(productInfoDto.getContentImgList(), productInfoDto.getId(), 2);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

    @Override
    public Page<ProductInfoVo> pageByOpen(Long categoryId, Long subCategoryId, ProductInfoSelectDto dto) {
        IWrapper<ProductInfo> wrapper = getWrapper();
        wrapper.orderByAsc("pi", ProductInfo::getSort);
        wrapper.eq("pi", ProductInfo::getStatus, "1");
        wrapper.eq("pi", ProductInfo::getCategoryId, categoryId);
        //子类目“全部”为 0
        if (0 != subCategoryId){
            wrapper.eq("pi", ProductInfo::getSubCategoryId, subCategoryId);
        }
        Page<ProductInfoVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }
}
