package com.fjhx.xmhjc.service.website.impl;

import cn.hutool.core.util.ObjectUtil;
import com.fjhx.xmhjc.constants.LoginConstant;
import com.fjhx.xmhjc.entity.website.po.WebsiteUsers;
import com.fjhx.xmhjc.mapper.website.WebsiteUsersMapper;
import com.fjhx.xmhjc.service.website.WebsiteUsersService;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.ruoyi.common.utils.sign.Md5Utils;
import org.springframework.stereotype.Service;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fjhx.xmhjc.entity.website.vo.WebsiteUsersVo;
import com.fjhx.xmhjc.entity.website.dto.WebsiteUsersSelectDto;
import com.ruoyi.common.utils.wrapper.IWrapper;
import com.fjhx.xmhjc.entity.website.dto.WebsiteUsersDto;
import cn.hutool.core.bean.BeanUtil;

import java.util.List;
import java.util.Map;
import java.util.Optional;

/**
 * <p>
 * 首页用户 服务实现类
 * </p>
 *
 * @author hj
 * @since 2023-11-17
 */
@Service
public class WebsiteUsersServiceImpl extends ServiceImpl<WebsiteUsersMapper, WebsiteUsers> implements WebsiteUsersService {

    @Override
    public List<WebsiteUsersVo> getList(WebsiteUsersSelectDto dto) {
        IWrapper<WebsiteUsers> wrapper = getWrapper();
        wrapper.orderByDesc("wu", WebsiteUsers::getId);
        List<WebsiteUsersVo> list = this.baseMapper.getList(wrapper);
        return list;
    }

    @Override
    public Page<WebsiteUsersVo> getPage(WebsiteUsersSelectDto dto) {
        IWrapper<WebsiteUsers> wrapper = getWrapper();
        wrapper.orderByDesc("wu", WebsiteUsers::getId);
        Page<WebsiteUsersVo> page = this.baseMapper.getPage(dto.getPage(), wrapper);
        return page;
    }

    @Override
    public WebsiteUsersVo detail(Long id) {
        WebsiteUsers WebsiteUsers = this.getById(id);
        WebsiteUsersVo result = BeanUtil.toBean(WebsiteUsers, WebsiteUsersVo.class);
        return result;
    }

    @Override
    public void add(WebsiteUsersDto websiteUsersDto) {
        this.save(websiteUsersDto);
    }

    @Override
    public void edit(WebsiteUsersDto websiteUsersDto) {
        this.updateById(websiteUsersDto);
    }

    @Override
    public void delete(Long id) {
        this.removeById(id);
    }

    @Override
    public void register(WebsiteUsersDto websiteUsersDto) {
        websiteUsersDto.setSolid(LoginConstant.SOLID);
        websiteUsersDto.setPassword(Md5Utils.hash(LoginConstant.SOLID + websiteUsersDto.getPassword()));
        this.save(websiteUsersDto);
    }

    @Override
    public Optional<WebsiteUsers> getByUserName(String userName) {
        return this.lambdaQuery().eq(WebsiteUsers::getUserName, userName).oneOpt();
    }


    @Override
    public String getAuthorName(Long author) {
        WebsiteUsers websiteUsers = this.getById(author);
        return ObjectUtil.isNull(websiteUsers) ? "" : websiteUsers.getUserName();
    }

    @Override
    public String getAuthorName(Long author, Map<Long, WebsiteUsers> websiteUsersMap) {
        WebsiteUsers websiteUsers = websiteUsersMap.get(author);
        if (ObjectUtil.isNull(websiteUsers)) {
            websiteUsers = this.getById(author);
            websiteUsersMap.put(author, websiteUsers);
        }
        return ObjectUtil.isNull(websiteUsers) ? "" : websiteUsers.getUserName();
    }
}
